@@ -5,9 +5,10 @@
 # Copyright 2013, John McNamara, jmcnamara@cpan.org
 #
 import re
+import sys
 from warnings import warn
 
-
+COL_NAMES = {}
 range_parts = re.compile(r'(\$?)([A-Z]{1,3})(\$?)(\d+)')
 
 
@@ -25,6 +26,20 @@ def xl_rowcol_to_cell(row, col, row_abs=0, col_abs=0):
     return col_str + row_abs + str(row)
 
 
+def xl_rowcol_to_cell_fast(row, col):
+    """
+    Optimised version of the xl_rowcol_to_cell function.
+
+    """
+    if col in COL_NAMES:
+        col_str = COL_NAMES[col]
+    else:
+        col_str = xl_col_to_name(col)
+        COL_NAMES[col] = col_str
+
+    return col_str + str(row + 1)
+
+
 def xl_col_to_name(col_num, col_abs=0):
     """
     TODO. Add Utility.py docs.
@@ -464,3 +479,15 @@ def get_sparkline_style(style_id):
     ]
 
     return styles[style_id]
+
+
+def encode_utf8(string):
+    """
+    Encode any strings passed by the user to UTF8 in Python 2.
+
+    """
+    if string is None or sys.version_info >= (3, 0):
+        return string
+    else:
+        return string.encode('utf-8')
+
